/*********************************************************************
 Copyright (C) 2004 New Zealand Digital Library, http://www.nzdl.org

 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2 of the License, or
 (at your option) any later version.

 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
***********************************************************************/

package vishnu.util;

import org.w3c.dom.Node;
import org.w3c.dom.Element;
import org.w3c.dom.NodeList;

public class XMLUtil {
    
    /** returns the (first) child element with the given name */
    public static Node getChildByTagName(Node n, String name) {

	Node child = n.getFirstChild();
	while (child!=null) {
	    if (child.getNodeName().equals(name)) {
		return child;
	    }
	    child = child.getNextSibling();
	}
	return null; //not found
    }

    /** takes a list of elements, and returns an array of strings 
     * of the values of attribute att_name */
    public static String [] getAttributeValuesFromList(Element list,
						       String att_name) {
	
	NodeList children = list.getChildNodes();
	
	int num_nodes = children.getLength();
	String []ids = new String[num_nodes];
	for (int i=0; i<num_nodes; i++) {
	    Element e = (Element)children.item(i);
	    String id = e.getAttribute(att_name);	    
	    ids[i] = id;	    
	}
	
	return ids;
    }

    /** extracts the text out of a node */
    public static String getNodeText(Element param) {
	param.normalize();
	Node n = param.getFirstChild();
	while (n!=null && n.getNodeType() !=Node.TEXT_NODE) {
	    n=n.getNextSibling();
	}
	if (n == null) {
	    return "";
	}
	return n.getNodeValue();
    }

}
